Contact us
===============================================================================

We at LINCC Frameworks pride ourselves on being a friendly bunch!

If you're encountering issues, have some gnarly dataset, have ideas for
making our products better, or pretty much anything else, reach out!

* Open an issue in our github repo for hats-import
    * https://github.com/astronomy-commons/hats-import/issues/new
* Start a new github discussion
    * https://github.com/astronomy-commons/hats-import/discussions/new/choose
* If you're on LSST Discovery Alliance slack, so are we!
    * `#lincc-frameworks-qa <https://lsstc.slack.com/archives/C062LG1AK1S>`__
    * `#lincc-frameworks-lsdb <https://lsstc.slack.com/archives/C04610PQW9F>`__
* Join the working group, where we discuss HATS standardization and early results
    * Google group: `hipscat-wg@googlegroups.com <https://groups.google.com/g/hipscat-wg>`__
    * You can listen in to demo meetings, or ask questions during co-working sessions. 
      Events are published on a google calendar, embedded below.
    * Key:
        * "HATS/LSDB Working Meeting" - Drop-in co-working/office hours. 
        * "HATS/LSDB Europe Working group" - Intended as European time zone friendly
          discussion of HATS and LSDB. Generally open.
        * "HATS/LSDB Monthly Demos" - A more structured telecon, with updates from
          developers and collaborators, and HATS standardization planning.
        * "LINCC Tech Talk" - Tech Talk series for software spanning LSST.
        * "LINCC Frameworks Office Hours" - General office hours for anything 
          related to software maintained by LINCC Frameworks, during LINCC 
          incubators, or general software advice.

.. raw:: html

   <iframe src="https://calendar.google.com/calendar/embed?height=600&wkst=1&ctz=America%2FNew_York&showPrint=0&src=Y180YTU1MTFiMDJiNjQ0OTlkNzIxNGE3Y2Y1NWY3NTE3NTY5YmE5NjQ1Y2FiMWM0YzA4YTdjYTQxYTIwNDE3YWQ1QGdyb3VwLmNhbGVuZGFyLmdvb2dsZS5jb20&src=NWI3MDkyYTAxOTZlMjkwODQ4ODEwOGYzMTk2NjM3Yjg0MzU4ZWNlNjIwMzJkYTVhYzY4ZWRjMGIwNGM5ZWFkNUBncm91cC5jYWxlbmRhci5nb29nbGUuY29t&color=%23F4511E&color=%23F09300" style="border:solid 1px #777" width="800" height="600" frameborder="0" scrolling="no"></iframe>

However you reach out, we want to make sure that any discourse is open and 
inclusive, and we ask that everyone involved read and adhere to the 
`LINCC Frameworks Code of Conduct <https://lsstdiscoveryalliance.org/programs/lincc-frameworks/code-conduct/>`__
